workspace "NextJS Training Solution Architecture" "The NextJS-based app created during the introductory training" {

    !identifiers hierarchical

    model {
        customer = person "Customer"
        admin = person "System Administrator"
	
        pgadmin = softwareSystem "pgAdmin 4 PostgreSQL Management Server" 

        ss = softwareSystem "NextJS Invoicing and Revenue Application" {
            wa = container "NextJS Web Application"
            db = container "NextJS App Database Schema" {
                tags "Database"
            }
            db_scripts = container "DBScripts.zip" "Initialization DB Scripts Archive" {
                technology "ZIP file"
		init_seed = component "Initialization DB Scripts (seed.mjs)" {
			technology "ECMAScript / JavaScript"
		}
            }
	db_scripts.init_seed -> db "Seeds the DB" "SQL:5432"
        wa -> db "Reads from and writes to" "SQL:5432"
        }     

        customer -> ss.wa "Uses" "HTTP:3000"
        admin -> ss.db_scripts.init_seed "Runs pnpm seed"
        admin -> pgadmin "Monitors and manages PostgreSQL DB" "HTTP:5050"
        pgadmin -> ss.db "Reads from and writes to" "HTTP:5432"
	
	deploymentEnvironment "Development Environment" {
	    deploymentNode "Developer Laptop" "" "Microsoft Windows 11 or Apple macOS" {
		
		deploymentNode "Docker Container - NodeJS Application Server" "" "Docker" {
                    deploymentNode "Web Server" "" "NodeJS 22.0" {
                        developerNextJSInstance = containerInstance ss.wa
                    }
                }

		deploymentNode "PC Filesystem" "" "" {
                    developerDatabaseScripts = containerInstance ss.db_scripts
                }

		deploymentNode "Docker Container - pgAdmin4 Server" "" "Docker" {
                    deploymentNode "pgAdmin Server" "" "pgAdmin4" {
                        developerPgadminInstance = softwareSystemInstance pgadmin
                    }
                }           
			

		deploymentNode "Docker Container - Database Server" "" "Docker" {
                    deploymentNode "Database Server" "" "PostreSQL alpine 15.0" {
                        developerDatabaseInstance = containerInstance ss.db
                    }
                }
	    }	
	}
        
    }

    views {
        systemContext ss "Diagram1" {
            include *
            autolayout lr
        }

        container ss "Diagram2" {
            include *
            autolayout lr
        }

	component ss.db_scripts {
	    include *
	    autolayout lr	
	}

	deployment ss "Development Environment" "DevelopmentDeployment" {
	    include *
	    #animation {
		#developerNextJSInstance
		#developerPgadminInstance
		#developerDatabaseScripts
		#developerDatabaseInstance
	    #}
	    autolayout
            description "An example deployment environment for the NextJS application development"		
	}

        styles {
            element "Element" {
                color #ffffff
            }
            element "Person" {
                background #05527d
                shape person
            }
            element "Software System" {
                background #066296
            }
            element "Container" {
                background #0773af
            }
	    element "Component" {
		background #00cc00
	    }
            element "Database" {
                shape cylinder
            }
        }
    }

    configuration {
        scope softwaresystem
    }

}
